@@ -27,13 +27,13 @@
 
 import re
 from collections import namedtuple
-from typing import Set, Tuple
+from typing import Tuple
 
 import numpy as np
-from equilibrator_cache import Compound
+from equilibrator_cache import PROTON_INCHI_KEY, Compound
 from equilibrator_cache.thermodynamic_constants import legendre_transform
 
-from . import Q_, R, ccache, ureg
+from . import Q_, ureg
 
 
 AQUEOUS_PHASE_NAME = "aqueous"
@@ -232,6 +232,11 @@ class PhasedCompound(object):
         """Get the compound's InChIKey."""
         return self.compound.inchi_key
 
+    @property
+    def is_proton(self) -> bool:
+        """Return True if this compound is a proton."""
+        return self.compound.inchi_key == PROTON_INCHI_KEY
+
     @property
     def id(self) -> int:
         """Get the compound's equilibrator internal ID."""
@@ -298,9 +303,9 @@ class PhasedCompound(object):
         :param abundance: the new abundance in the correct units
         :return:
         """
-        assert self.compound != ccache.proton, (
-            f"Cannot directly change the relative abundance of H+. Use the pH "
-            f"parameter instead for adjusting this value."
+        assert not self.is_proton, (
+            "Cannot directly change the relative abundance of H+. Use the pH "
+            "parameter instead for adjusting this value."
         )
 
         self.condition.abundance = abundance
@@ -308,7 +313,7 @@ class PhasedCompound(object):
     @property
     def ln_abundance(self) -> float:
         """Return the log of the abundance (for thermodynamic calculations)."""
-        if self.compound == ccache.proton:
+        if self.is_proton:
             # Since pH is an environmental parameter, we do not use the
             # concentration of protons for energy calculations
             return 0.0
@@ -317,7 +322,7 @@ class PhasedCompound(object):
     @property
     def ln_physiological_abundance(self) -> float:
         """Return the log of the default physiological abundance."""
-        if self.compound == ccache.proton:
+        if self.is_proton:
             # Since pH is an environmental parameter, we do not use the
             # concentration of protons for energy calculations
             return 0.0
@@ -328,9 +333,9 @@ class PhasedCompound(object):
         """Check if the abundance is physiological."""
         return self.condition.is_physiological
 
-    @ureg.check(None, None, "[concentration]", "[temperature]")
+    @ureg.check(None, None, "[concentration]", "[temperature]", "")
     def get_stored_standard_dgf_prime(
-        self, p_h: Q_, ionic_strength: Q_, temperature: Q_
+        self, p_h: Q_, ionic_strength: Q_, temperature: Q_, p_mg: Q_
     ) -> Q_:
         """Return the stored formation energy of this phased compound.
 
@@ -340,23 +345,20 @@ class PhasedCompound(object):
         :param p_h:
         :param ionic_strength:
         :param temperature:
+        :param p_mg:
         :return: standard_dgf_prime (in kJ/mol)
         """
         ms = self.get_stored_microspecie()
         if ms is not None:
             # for compound-phase pairs in this dictionary use the stored
             # value and transform directly using the Legendre transform
-            return (
-                ms.standard_dgf
-                + legendre_transform(
-                    p_h=p_h,
-                    ionic_strength=ionic_strength,
-                    temperature=temperature,
-                    num_protons=ms.num_protons,
-                    charge=ms.charge,
-                )
-                * R
-                * temperature
+            return ms.standard_dgf + legendre_transform(
+                p_h=p_h,
+                ionic_strength=ionic_strength,
+                temperature=temperature,
+                p_mg=p_mg,
+                num_protons=ms.num_protons,
+                charge=ms.charge,
             )
         else:
             # for all other compounds, we will use component_contribution
@@ -413,14 +415,3 @@ class PhasedCompound(object):
             "ln_abundance": self.ln_abundance,
             "microspecies": ms_list,
         }
-
-    @property
-    def first_name(self):
-        """Get the first name that appears in the compound-cache."""
-        # TODO: use MetaNetX database to get the first name
-        return ccache.get_compound_first_name(self.compound)
-
-    @property
-    def names(self) -> Set[str]:
-        """Get the set of all associated names in the compound cache."""
-        return ccache.get_compound_names(self.compound)
